@@ -1,5 +1,5 @@
 
-# $Id: Ebay.pm,v 2.262 2013-08-21 01:15:16 Martin Exp $
+# $Id: Ebay.pm,v 2.263 2013-11-29 00:20:54 Martin Exp $
 
 =head1 NAME
 
@@ -53,9 +53,6 @@ field is a string containing the high bid or starting bid as a
 human-readable monetary value in seller-native units, e.g. "$14.95" or
 "GBP 6.00".
 
-In the resulting L<WWW::Search::Result> objects, the category() field
-contains the Ebay category number.
-
 In the resulting L<WWW::Search::Result> objects, the sold() field will
 be non-zero if the item has already sold.  (Only if you're using
 WWW::Search::Ebay::Completed)
@@ -67,7 +64,7 @@ the count of items matching your query in each category and
 subcategory.  (Special thanks to Nick Lokkju for this code!)  For
 example:
 
-  $oSearch->{category} = [
+  $oSearch->{categories} = [
           {
             'ID' => '1',
             'Count' => 19,
@@ -139,7 +136,7 @@ use WWW::SearchResult 2.072;
 use WWW::Search::Result;
 
 our
-$VERSION = do { my @r = (q$Revision: 2.262 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.263 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 our $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 my $cgi = new CGI;
 
@@ -756,7 +753,7 @@ sub _parse_tree
     $self->approximate_result_count(1);
     return 1;
     } # if
-  my $iHits = 0;
+
   # First, see if: there were zero results and eBay automatically did
   # a spell-check and searched for other words (or searched for a
   # subset of query terms):
@@ -781,6 +778,7 @@ sub _parse_tree
       return 0;
       } # if
     } # if
+
   # See if our query was completely replaced by a similar-spelling query:
   my $oLI = $tree->look_down(_tag => 'li',
                              class => 'ebInf',
@@ -793,6 +791,20 @@ sub _parse_tree
       return 0;
       } # if
     } # if
+
+  # See if our category-only query was replaced by a global query:
+  my $oP = $tree->look_down(_tag => 'p',
+                             class => 'sm-md',
+                            );
+  if (ref $oP)
+    {
+    my $s = $oP->as_text;
+    if (($s =~ m/0 results found in the/) && ($s =~ m/so we searched in all categories/))
+      {
+      return 0;
+      } # if
+    } # if
+
   # The hit count is in a FONT tag:
   my @aoFONT = $self->_get_result_count_elements($tree);
  FONT:
@@ -864,6 +876,7 @@ sub _parse_tree
     # use File::Slurp;
     # write_file('no-results.html', $self->{response}->content);
     } # unless
+  my $iHits = 0;
   my $qrItemNum = qr{(\d{11,13})};
  TD:
   foreach my $oTDtitle (@aoTD)
@@ -883,9 +896,9 @@ sub _parse_tree
     # next TD unless ($oURI =~ m!ViewItem!);
     next TD if ($oURI !~ m!$qrItemNum!);
     my $iItemNum = $1;
+    print STDERR " DDD   iItemNum ===$iItemNum===\n" if (1 < $self->{_debug});
     my $iCategory = -1;
     $iCategory = $1 if ($oURI =~ m!QQcategoryZ(\d+)QQ!);
-    print STDERR " DDD   iItemNum ===$iItemNum===\n" if (1 < $self->{_debug});
     if ($oURI->as_string =~ m!QQitemZ(\d+)QQ!)
       {
       # Convert new eBay links to old reliable ones:
